#
# spec file for package pdf2djvu
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pdf2djvu
Version:        0.8.1
Release:        5.4
Summary:        PDF to DjVu Converter
License:        GPL-2.0
Group:          Productivity/Publishing/PDF
Url:            http://jwilk.net/software/pdf2djvu
Source0:        https://bitbucket.org/jwilk/pdf2djvu/downloads/%{name}-%{version}.tar.xz
Source1:        https://bitbucket.org/jwilk/pdf2djvu/downloads/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  djvulibre
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(GraphicsMagick++)
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.21
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(poppler) >= 0.11.1
# Requires to run tests correctly.
BuildRequires:  liberation-fonts
BuildRequires:  python-imaging
BuildRequires:  python-nose
Requires:       djvulibre
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pdf2djvu creates DjVu files from PDF files. It's able to extract:
graphics, text layer, hyperlinks, document outline (bookmarks) and
metadata.

%lang_package

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} --with-man

%check
%if 0%{?suse_version} >= 1210
make test
%endif

%files
%defattr(-,root,root,-)
%doc doc/{changelog,COPYING,cjk.txt,credits.txt,djvudigital.txt}
%{_bindir}/%{name}
%{_mandir}/man?/*

%files lang -f %{name}.lang
%defattr(-,root,root,-)
%dir %{_mandir}/uk/
%dir %{_mandir}/uk/man1/

%changelog
* Mon Aug 17 2015 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Fix “--fg-colors=N” when GraphicsMagick was compiled with
    QuantumDepth > 8.
  * Report GraphicsMagick's QuantumDepth in “--version”.
  * Build with “-Werror=narrowing”.
  * Document what software is required to run the tests.
  * Improve the test suite.
- Correct: BuildRequires: pkgconfig(ddjvuapi) >= 3.5.21;
  pkgconfig(poppler) >= 0.11.1.
* Sun Aug  9 2015 lazy.kent@opensuse.org
- Update to 0.8.
  * Don't hardcode the Python interpreter path in script shebangs;
    use “#!/usr/bin/env python” instead.
  * Don't silently ignore --loss-level when used without
  - -monochrome.
  * Add sanity check that output file is distinct from all input
    files.
  * Apply NFKC normalization on characters from the Alphabetic
    Presentation Forms block (U+FB00–U+FB4F), even when --no-nfkc
    were specified. This is what Poppler (≥ 0.19) does by default.
  * Fail early if duplicate page numbers were specified in
  - p/--pages.
  * Fail early on duplicate page identifiers and duplicate page
    titles.
  * Make --help and --version return with exit code 0.
  * Improve the configure script:
    + Check if Poppler xpdf headers exist.
    + Add option for disabling PStreams (--without-pstreams).
  * Change the order libraries on linker command line. Move
    libraries provided by the LIBS configure variable to the end.
  * Use the reentrant S-expression output API when it's available
    (DjVuLibre >= 3.5.25).
  * Improve error handling.
  * Improve the test suite.
  * Improve documentation:
    + Simplify documentation about build dependencies.
    + Document that pkg-config is required for building.
    + Update poppler-data download URL.
  * Update Polish, Portuguese, German, Russian translations and the
    French translation of the manual page.
* Mon May 11 2015 lazy.kent@opensuse.org
- Update to 0.7.21.
  * Fix insecure use of /tmp when executing c44(1).
* Fri May  8 2015 lazy.kent@opensuse.org
- Update to 0.7.20.
  * Don't use djvused for setting document outline.
  * Test suite: automatically skip tests that require features that
    were not enabled at build time.
  * Improve reporting of versions of the libraries in --version and
    XMP metadata.
  * Update the homepage URL and the bug tracker URLs, in
    documentation and code.
  * Update Portuguese, Russian, German and Ukrainian translations.
- Add for tests BuildRequires: python-imaging.
- Correct the URL tag.
* Thu Mar 12 2015 lazy.kent@opensuse.org
- Add %%check section to run 'make test'.
- Update the keyring file.
* Mon Mar  9 2015 p.drouand@gmail.com
- Update to version 0.7.19
  * Fix build failure with Poppler ≥ 0.31.
    https://code.google.com/p/pdf2djvu/issues/detail?id=99
- Remove gpg-offline usage; OBS handles sources verification
- Update download Url
- Do not use %%doc with manpages; it's redundant
- Changes in 0.7.18.
  * Make the xml2c script more portable.
  * In C++11 mode, use “decltype” instead of “typeof”.
  * Fix build failure with libc++ in C++98 mode.
  * Use the standard AC_OPENMP macro in the configure script
    (instead of 3rd-party AX_OPENMP).
  * Use HTTPS URLs when they are available, in documentation and
    code.
  * Add Portuguese translation; add French translation of the
    manual page; fix capitalization error in the German manual
    page.
  * Drop support for Poppler < 0.11.1.
  * Improve error handling.
* Fri May 31 2013 lazy.kent@opensuse.org
- Update to 0.7.17.
  * Fix build failure with Poppler ≥ 0.23.
- Changes in 0.7.16.
  * Fix build failure with Poppler ≥ 0.21.1.
- Drop pdf2djvu-poppler.patch (fixed upstream).
- Verify GPG signature.
* Tue Nov 13 2012 idonmez@suse.com
- add pdf2djvu-poppler.patch to fix compile with new poppler
* Sun Oct  7 2012 lazy.kent@opensuse.org
- Update to 0.7.15.
  + Fix build failure with Poppler ≥ 0.21.
* Wed Sep 19 2012 lazy.kent@opensuse.org
- Update to 0.7.14.
  + Ignore links with no action. (Previously such links would cause
    segfault).
  + Update German, Russian, Ukrainian translations.
* Mon Jun  4 2012 lazy.kent@opensuse.org
- Update to 0.7.13.
  + Fix build failure with Poppler ≥ 0.19.
  + Update German, Russian, Ukrainian translations.
  + Add Ukrainian translation of the manual page.
- Disable tests (Python problem).
* Tue Feb 28 2012 lazy.kent@opensuse.org
- Split off language package.
- Use pkgconfig(*) build dependencies.
* Sun Jan 22 2012 lazy.kent@opensuse.org
- Update to 0.7.12
  + Fix resolution detection.
  + Add Ukrainian translation.
* Thu Oct  6 2011 lazy.kent@opensuse.org
- Update to 0.7.11
  + Fix build failure with Poppler >= 0.17.
- Removed pdf2djvu-poppler-0.18.patch (fixed upstream).
- Removed obsolete "clean" section.
* Tue Sep 20 2011 vuntz@opensuse.org
- Add pdf2djvu-poppler-0.18.patch: fix build with poppler
  0.17/0.18.
* Sat Aug 20 2011 lazy.kent@opensuse.org
- Update to 0.7.10
  + Fix the --monochrome option.
  + Fix crash with --no-metadata.
* Thu Aug 18 2011 lazy.kent@opensuse.org
- Update to 0.7.9
  + Add Russian translation.
* Mon Jul 25 2011 lazy.kent@opensuse.org
- Update to 0.7.8
  + Add support for merging multiple PDFs into a single DjVu file.
  + Add German translation.
* Fri May 27 2011 lazy.kent@opensuse.org
- Build requires ghostscript-fonts-std to run tests correctly
- Use full URL for source
* Wed Mar 30 2011 lazy.kent@opensuse.org
- Update to 0.7.7
  + Fix build failure with GCC 4.6.
  + Make it possible to control how work is distributed between
    threads with the OMP_SCHEDULE variable.
* Sat Feb 19 2011 lazy.kent@opensuse.org
- Update to 0.7.6
- Man pages marked as docs
* Fri Jan 21 2011 lazy.kent@opensuse.org
- Don't make test in SLE
* Thu Jan 20 2011 lazy.kent@opensuse.org
- Update to 0.7.5
  + Document the use of TMPDIR environment variable.
- Make tests
- Added COPYING
* Sun Jun 13 2010 lazy.kent.suse@gmail.com
- Update to 0.7.4
  + Fix handling of the --pages option.
  + Fix build failure with GCC 4.2.
  + Make messages about missing features a bit more informative.
- Dropped obsolete patch
* Sat Jun 12 2010 lazy.kent.suse@gmail.com
- Fixed handling of the --pages option
* Mon May 24 2010 lazy.kent.suse@gmail.com
- Update to 0.7.3
  + Fix handling of the --indirect option.
* Sun May  2 2010 lazy.kent.suse@gmail.com
- Update to 0.7.2
  + Add the --fg-colors=black option.
  + Fix broken output with --fg-colors=web.
  + Fix crash with GraphicMagick ≥ 1.3.8.
  + Override number of threads set by GraphicsMagick.
- Added some docs
* Tue Apr 20 2010 lazy.kent.suse@gmail.com
- Update to 0.7.1
  + Speed up converting pages for which no foreground were
    detected.
* Sun Feb 28 2010 lazy.kent.suse@gmail.com
- Update to 0.7.0
  + Add support for parallel page rendering: options -j/--jobs.
* Fri Jan 15 2010 lazy.kent.suse@gmail.com
- Update to 0.6.2
  + Fix build failure without PStreams.
* Fri Jan 15 2010 lazy.kent.suse@gmail.com
- Update to 0.6.1
  + Add the --text-filter option.
- Added libGraphicsMagick++-devel, libxslt-devel and pstreams-devel
  to BuildRequires
* Fri Oct  2 2009 lazy.kent.suse@gmail.com
- Update to 0.6.0
  + New regression tests.
  + Add support for correcting XMP metadata.
  + Fix resolution detection (poppler ≥ 0.11.1 only).
* Thu Jul 30 2009 lazy.kent.suse@gmail.com
- Update to 0.5.11
  + Document how to deal with CJK PDFs.
* Sat Jul 11 2009 lazy.kent.suse@gmail.com
- Update to 0.5.10
  + Add Polish translation of the manual page.
* Tue Jun 30 2009 lazy.kent.suse@gmail.com
- Added djvulibre to Requires
* Thu Jun 18 2009 lazy.kent.suse@gmail.com
- Update to 0.5.9
  + Add Polish translation
* Mon Jun  1 2009 lazy.kent.suse@gmail.com
- Spec-file cleanup
* Sat May 16 2009 lazy.kent.suse@gmail.com
- Update to 0.5.8
  + Fix some rounding bugs.
* Thu May  7 2009 lazy.kent.suse@gmail.com
- Update to 0.5.7
  + Add the --guess-dpi option.
* Tue May  5 2009 lazy.kent.suse@gmail.com
- Update to 0.5.6
  + New default quantization algorithm.
  + Fix some character encoding issues.
  + Stricter requirements for pageid names.
  + Lift a limitation on number of pages in a bundled multi-page
    document.
* Sun May  3 2009 lazy.kent.suse@gmail.com
- Update to 0.5.5
  + Add the --pageid-template option.
  + Add the --page-title-template option.
  + Don't allow duplicate page identifies nor duplicate page
    titles.
  + More robust UTF-16 to UTF-8 conversion.
* Wed Apr 15 2009 lazy.kent.suse@gmail.com
- Update to 0.5.4
  + Add the --crop-text option.
* Wed Apr 15 2009 lazy.kent.suse@gmail.com
- Initial package created - 0.5.3
